@@ -19,7 +19,7 @@ staging = storage.get_staging()
 
 sdc1 = Partition.find_by_name(staging, "/dev/sdc1")
 
-sdc1.remove_descendants()
+sdc1.remove_descendants(View_REMOVE)
 
 print(staging)
 
