@@ -1,5 +1,5 @@
 /*
- * Copyright (c) [2017-2023] SUSE LLC
+ * Copyright (c) [2017-2025] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -378,6 +378,13 @@ namespace storage
     }
 
 
+    bool
+    MountPoint::Impl::is_read_only() const
+    {
+	return mount_options.contains("ro");
+    }
+
+
     void
     MountPoint::Impl::add_create_actions(Actiongraph::Impl& actiongraph) const
     {
